@@ -1,6 +1,7 @@
 #!/bin/bash
 
-sudo pacman -Syu --noconfirm --needed git make gcc python python-setuptools \
+sudo pacman -Syu --noconfirm --needed \
+    git make gcc patch python python-setuptools \
     python-numpy python-scipy python-matplotlib \
     python-pyqt5 qt5-webengine qt5-svg qt5-webkit \
     python-cairo python-opengl python-progressbar \
