@@ -1,5 +1,5 @@
 #!/bin/bash
 
-sudo yum -y install make gcc git python python-yaml python-matplotlib numpy \
+sudo yum -y install make gcc patch git python python-yaml python-matplotlib numpy \
     scipy python-requests python-coverage python-nose python-jinja2 \
     PyQt4 python-matplotlib-qt4
