@@ -32,6 +32,11 @@ import logging
 import ssl
 import socket
 
+try:
+    import certifi
+except ImportError:
+    certifi = None
+
 
 from pyrocko import util
 from pyrocko.util import DownloadError
@@ -45,6 +50,13 @@ try:
 except NameError:
     newstr = str
 
+
+if certifi:
+    g_cafile = certifi.where()
+else:
+    g_cafile = None
+
+
 logger = logging.getLogger('pyrocko.client.fdsn')
 
 g_url = '%(site)s/fdsnws/%(service)s/%(majorversion)i/%(method)s'
@@ -237,6 +249,8 @@ def _request(
     if allow_TLSv1:
         url_args['context'] = ssl.SSLContext(ssl.PROTOCOL_TLSv1)
 
+    url_args['cafile'] = g_cafile
+
     opener = None
 
     req = Request(url)
@@ -253,12 +267,13 @@ def _request(
         itry += 1
         try:
             urlopen_ = opener.open if opener else urlopen
-            while True:
-                try:
-                    resp = urlopen_(req, **url_args)
-                    break
-                except TypeError:
-                    del url_args['context']  # context not avail before 3.4.3
+            try:
+                resp = urlopen_(req, **url_args)
+            except TypeError:
+                # context and cafile not avail before 3.4.3, 2.7.9
+                url_args.pop('context', None)
+                url_args.pop('cafile', None)
+                resp = urlopen_(req, **url_args)
 
             logger.debug('Response: %s' % resp.getcode())
             if resp.getcode() == 204:
@@ -622,8 +637,6 @@ def event(
 
     :returns:
         See description of ``parsed`` argument above.
-
-
     '''
 
     service = 'event'
