@@ -11,7 +11,10 @@ import struct
 import weakref
 import math
 import shutil
-import fcntl
+try:
+    import fcntl
+except ImportError:
+    fcntl = None
 import copy
 import logging
 import re
@@ -22,7 +25,10 @@ from scipy import signal
 
 from . import meta
 from .error import StoreError
-from . import store_ext
+try:
+    from . import store_ext
+except ImportError:
+    store_ext = None
 from pyrocko import util, spit
 
 logger = logging.getLogger('pyrocko.gf.store')
@@ -113,7 +119,6 @@ sampling_check_eps = 1e-5
 
 
 class GFTrace(object):
-
     '''
     Green's Function trace class for handling traces from the GF store.
     '''
@@ -295,6 +300,10 @@ def get_extra_path(store_dir, key):
 
 class BaseStore(object):
 
+    @staticmethod
+    def lock_fn_(store_dir):
+        return os.path.join(store_dir, 'lock')
+
     @staticmethod
     def index_fn_(store_dir):
         return os.path.join(store_dir, 'index')
@@ -338,7 +347,7 @@ class BaseStore(object):
         self._deltat = None
         self._f_index = None
         self._f_data = None
-        self._end_values = None
+        self._records = None
         self.cstore = None
 
     def open(self):
@@ -393,24 +402,32 @@ class BaseStore(object):
             self.close()
 
     def lock(self):
-        if not self._f_index:
-            self.open()
+        if not fcntl:
+            lock_fn = self.lock_fn()
+            util.create_lockfile(lock_fn)
+        else:
+            if not self._f_index:
+                self.open()
 
-        while True:
-            try:
-                fcntl.lockf(self._f_index, fcntl.LOCK_EX)
-                break
+            while True:
+                try:
+                    fcntl.lockf(self._f_index, fcntl.LOCK_EX)
+                    break
 
-            except IOError as e:
-                if e.errno == errno.ENOLCK:
-                    time.sleep(0.01)
-                else:
-                    raise
+                except IOError as e:
+                    if e.errno == errno.ENOLCK:
+                        time.sleep(0.01)
+                    else:
+                        raise
 
     def unlock(self):
-        self._f_data.flush()
-        self._f_index.flush()
-        fcntl.lockf(self._f_index, fcntl.LOCK_UN)
+        if not fcntl:
+            lock_fn = self.lock_fn()
+            util.delete_lockfile(lock_fn)
+        else:
+            self._f_data.flush()
+            self._f_index.flush()
+            fcntl.lockf(self._f_index, fcntl.LOCK_UN)
 
     def put(self, irecord, trace):
         self._put(irecord, trace)
@@ -438,7 +455,6 @@ class BaseStore(object):
         return self.irecord_format() % irecord
 
     def close(self):
-
         if self.mode == 'w':
             if not self._f_index:
                 self.open()
@@ -452,6 +468,9 @@ class BaseStore(object):
             self._f_index.close()
             self._f_index = None
 
+        del self._records
+        self._records = None
+
         self.mode = ''
 
     def _get_record(self, irecord):
@@ -461,7 +480,9 @@ class BaseStore(object):
         return self._records[irecord]
 
     def _get(self, irecord, itmin, nsamples, decimate, implementation):
-        '''Retrieve complete GF trace from storage.'''
+        '''
+        Retrieve complete GF trace from storage.
+        '''
 
         if not self._f_index:
             self.open()
@@ -797,7 +818,7 @@ class BaseStore(object):
 
         delays = delays / deltat
         irecords2 = num.repeat(irecords, 2)
-        delays2 = num.empty(irecords2.size, dtype=num.float)
+        delays2 = num.empty(irecords2.size, dtype=float)
         delays2[0::2] = num.floor(delays)
         delays2[1::2] = num.ceil(delays)
         weights2 = num.repeat(weights, 2)
@@ -909,15 +930,13 @@ class BaseStore(object):
 
         self._records = records
 
-        self._end_values = self._records['end_value']
-
     def _save_index(self):
         self._f_index.seek(0)
         self._f_index.write(struct.pack(gf_store_header_fmt, self._nrecords,
                                         self.get_deltat()))
 
         if self._use_memmap:
-            del self._records
+            self._records.flush()
         else:
             self._f_index.seek(gf_store_header_fmt_size)
             self._records.tofile(self._f_index)
@@ -942,6 +961,9 @@ class BaseStore(object):
         else:
             return num.empty((0,), dtype=gf_dtype)
 
+    def lock_fn(self):
+        return BaseStore.lock_fn_(self.store_dir)
+
     def index_fn(self):
         return BaseStore.index_fn_(self.store_dir)
 
@@ -1540,11 +1562,13 @@ class Store(BaseStore):
         return os.path.join(self.store_dir, 'phases', phase_id + '.phase')
 
     def get_stored_phase(self, phase_id):
-        """Get stored phase from GF store
+        '''
+        Get stored phase from GF store.
 
         :returns: Phase information
         :rtype: :py:class:`pyrocko.spit.SPTree`
-        """
+        '''
+
         if phase_id not in self._phases:
             fn = self.phase_filename(phase_id)
             if not os.path.isfile(fn):
@@ -1699,7 +1723,7 @@ use `fomosto tttlsd` to fix holes.''' % w
             else:
                 raise MakeTimingParamsFailed(msg)
 
-        xs, tmins, tmaxs = num.array(data, dtype=num.float).T
+        xs, tmins, tmaxs = num.array(data, dtype=float).T
 
         tlens = tmaxs - tmins
 
@@ -1743,7 +1767,8 @@ use `fomosto tttlsd` to fix holes.''' % w
             vred=vred)
 
     def make_ttt(self, force=False):
-        '''Compute travel time tables.
+        '''
+        Compute travel time tables.
 
         Travel time tables are computed using the 1D earth model defined in
         :py:attr:`~pyrocko.gf.meta.Config.earthmodel_1d` for each defined phase
