@@ -53,6 +53,15 @@ def myctime(timestamp):
     return mystrftime(None, tt, ms)
 
 
+g_color_b = [plot.color(x) for x in (
+    'scarletred1', 'scarletred2', 'scarletred3',
+    'chameleon1', 'chameleon2', 'chameleon3',
+    'skyblue1', 'skyblue2', 'skyblue3',
+    'orange1', 'orange2', 'orange3',
+    'plum1', 'plum2', 'plum3',
+    'chocolate1', 'chocolate2', 'chocolate3')]
+
+
 class MarkerParseError(Exception):
     pass
 
@@ -82,8 +91,8 @@ class Marker(object):
                 'Unable to create marker from string: "%s"' % line)
 
         def parsedate(ymd, hms, sfs):
-            return calendar.timegm(
-                time.strptime(ymd+' '+hms, '%Y-%m-%d %H:%M:%S')) + float(sfs)
+            return util.to_time_str(calendar.timegm(
+                time.strptime(ymd+' '+hms, '%Y-%m-%d %H:%M:%S'))) + float(sfs)
 
         try:
             toks = line.split()
@@ -119,7 +128,8 @@ class Marker(object):
 
     @staticmethod
     def save_markers(markers, fn, fdigits=3):
-        '''Static method to write marker objects to file.
+        '''
+        Static method to write marker objects to file.
 
         :param markers: list of :py:class:`Marker` objects
         :param fn: filename as string
@@ -194,25 +204,14 @@ class Marker(object):
 
     def __init__(self, nslc_ids, tmin, tmax, kind=0):
         self.set(nslc_ids, tmin, tmax)
-        c = plot.color
-
-        self.color_a = [c(x) for x in (
-            'aluminium4', 'aluminium5', 'aluminium6')]
-
-        self.color_b = [c(x) for x in (
-            'scarletred1', 'scarletred2', 'scarletred3',
-            'chameleon1', 'chameleon2', 'chameleon3',
-            'skyblue1', 'skyblue2', 'skyblue3',
-            'orange1', 'orange2', 'orange3',
-            'plum1', 'plum2', 'plum3',
-            'chocolate1', 'chocolate2', 'chocolate3')]
-
         self.alerted = False
         self.selected = False
         self.kind = kind
+        self.active = False
 
     def set(self, nslc_ids, tmin, tmax):
-        '''Set ``nslc_ids``, start time and end time of :py:class:`Marker`
+        '''
+        Set ``nslc_ids``, start time and end time of :py:class:`Marker`.
 
         :param nslc_ids: list or set of (network, station, location, channel)
             tuples
@@ -220,11 +219,12 @@ class Marker(object):
         :param tmax: end time
         '''
         self.nslc_ids = nslc_ids
-        self.tmin = tmin
-        self.tmax = tmax
+        self.tmin = util.to_time_float(tmin)
+        self.tmax = util.to_time_float(tmax)
 
     def set_kind(self, kind):
-        '''Set kind of :py:class:`Marker`
+        '''
+        Set kind of :py:class:`Marker`.
 
         :param kind: (optional) integer to distinguish groups of markers
                         (color-coded)
@@ -232,15 +232,20 @@ class Marker(object):
         self.kind = kind
 
     def get_tmin(self):
-        '''Get *start time* of :py:class:`Marker`'''
+        '''
+        Get *start time* of :py:class:`Marker`.
+        '''
         return self.tmin
 
     def get_tmax(self):
-        '''Get *end time* of :py:class:`Marker`'''
+        '''
+        Get *end time* of :py:class:`Marker`.
+        '''
         return self.tmax
 
     def get_nslc_ids(self):
-        '''Get marker's network-station-location-channel pattern.
+        '''
+        Get marker's network-station-location-channel pattern.
 
         :returns: list or set of (network, station, location, channel) tuples
 
@@ -258,23 +263,26 @@ class Marker(object):
     def set_alerted(self, state):
         self.alerted = state
 
-    def set_selected(self, state):
-        self.selected = state
-
     def match_nsl(self, nsl):
-        '''See documentation of :py:func:`pyrocko.util.match_nslc`'''
+        '''
+        See documentation of :py:func:`pyrocko.util.match_nslc`.
+        '''
         patterns = ['.'.join(x[:3]) for x in self.nslc_ids]
         return util.match_nslc(patterns, nsl)
 
     def match_nslc(self, nslc):
-        '''See documentation of :py:func:`pyrocko.util.match_nslc`'''
+        '''
+        See documentation of :py:func:`pyrocko.util.match_nslc`.
+        '''
         patterns = ['.'.join(x) for x in self.nslc_ids]
         return util.match_nslc(patterns, nslc)
 
     def one_nslc(self):
-        '''If one *nslc_id* defines this marker return this id.
+        '''
+        If one *nslc_id* defines this marker return this id.
         If more than one *nslc_id* is defined in the :py:class:`Marker`s
-        *nslc_ids* raise :py:exc:`MarkerOneNSLCRequired`.'''
+        *nslc_ids* raise :py:exc:`MarkerOneNSLCRequired`.
+        '''
         if len(self.nslc_ids) != 1:
             raise MarkerOneNSLCRequired()
 
@@ -284,7 +292,9 @@ class Marker(object):
         return ''
 
     def copy(self):
-        ''' Get a copy of this marker. '''
+        '''
+        Get a copy of this marker.
+        '''
         return copy.deepcopy(self)
 
     def __str__(self):
@@ -366,11 +376,18 @@ class Marker(object):
         from .qt_compat import qc, qg
         from . import util as gui_util
 
-        if self.selected or self.alerted or not self.nslc_ids:
+        color = self.select_color(g_color_b)
+        pen = qg.QPen(qg.QColor(*color))
+        pen.setWidth(2)
+        p.setPen(pen)
 
-            color = self.select_color(self.color_b)
-            pen = qg.QPen(qg.QColor(*color))
-            pen.setWidth(2)
+        umin = time_projection(self.tmin)
+        umax = time_projection(self.tmax)
+        v0, v1 = y_projection.get_out_range()
+        line = qc.QLineF(umin-1, v0, umax+1, v0)
+        p.drawLine(line)
+
+        if self.selected or self.alerted or not self.nslc_ids:
             linepen = qg.QPen(pen)
             if self.selected or self.alerted:
                 linepen.setStyle(qc.Qt.CustomDashLine)
@@ -387,13 +404,11 @@ class Marker(object):
 
             def drawline(t):
                 u = time_projection(t)
-                v0, v1 = y_projection.get_out_range()
                 line = qc.QLineF(u, v0, u, v1)
                 p.drawLine(line)
 
             def drawtriangles(t):
                 u = time_projection(t)
-                v0, v1 = y_projection.get_out_range()
                 t = qg.QPolygonF(utriangle)
                 t.translate(u, v0)
                 p.drawConvexPolygon(t)
@@ -424,7 +439,7 @@ class Marker(object):
         if self.nslc_ids and not self.match_nslc(tr.nslc_id):
             return
 
-        color = self.select_color(self.color_b)
+        color = self.select_color(g_color_b)
         pen = qg.QPen(qg.QColor(*color))
         pen.setWidth(2)
         p.setPen(pen)
@@ -467,7 +482,7 @@ class Marker(object):
         except trace.NoData:
             pass
 
-        color = self.select_color(self.color_b)
+        color = self.select_color(g_color_b)
         pen = qg.QPen(qg.QColor(*color))
         pen.setWidth(2)
         p.setPen(pen)
@@ -524,6 +539,7 @@ class Marker(object):
         else:
             self._event_hash = None
             self._event_time = None
+        self.active = False
 
     def convert_to_event_marker(self, lat=0., lon=0.):
         if isinstance(self, EventMarker):
@@ -535,25 +551,26 @@ class Marker(object):
         self.__class__ = EventMarker
         self._event = model.Event(lat, lon, time=self.tmin, name='Event')
         self._event_hash = self._event.get_hash()
-        self._active = False
+        self.active = False
         self.tmax = self.tmin
         self.nslc_ids = []
 
 
 class EventMarker(Marker):
-    """
-    An EventMarker is a GUI element representing a seismological event
+    '''
+    GUI element representing a seismological event.
 
     :param event: A :py:class:`pyrocko.model.Event` object containing meta
         information of a seismological event
     :param kind: (optional) integer to distinguish groups of markers
     :param event_hash:  (optional) hash code of event (see:
         :py:meth:`pyrocko.model.Event.get_hash`)
-    """
+    '''
+
     def __init__(self, event, kind=0, event_hash=None):
         Marker.__init__(self, [], event.time, event.time, kind)
         self._event = event
-        self._active = False
+        self.active = False
         self._event_hash = event_hash
 
     def get_event_hash(self):
@@ -562,9 +579,6 @@ class EventMarker(Marker):
         else:
             return self._event.get_hash()
 
-    def set_active(self, active):
-        self._active = active
-
     def label(self):
         t = []
         mag = self._event.magnitude
@@ -602,11 +616,13 @@ class EventMarker(Marker):
         label_bg = qg.QBrush(qg.QColor(255, 255, 255))
         gui_util.draw_label(
             p, u, v0-10., self.label(), label_bg, 'CB',
-            outline=self._active)
+            outline=self.active)
 
     def get_event(self):
-        '''Return an instance of the :py:class:`pyrocko.model.Event` associated
-        to this :py:class:`EventMarker`'''
+        '''
+        Return an instance of the :py:class:`pyrocko.model.Event` associated
+        to this :py:class:`EventMarker`
+        '''
         return self._event
 
     def draw_trace(self, viewer, p, tr, time_projection, track_projection,
@@ -727,8 +743,10 @@ class PhaseMarker(Marker):
         return ''.join(t)
 
     def get_event(self):
-        '''Return an instance of the :py:class:`pyrocko.model.Event` associated
-        to this :py:class:`EventMarker`'''
+        '''
+        Return an instance of the :py:class:`pyrocko.model.Event` associated
+        to this :py:class:`EventMarker`
+        '''
         return self._event
 
     def get_event_hash(self):
@@ -779,6 +797,7 @@ class PhaseMarker(Marker):
         del self._automatic
         del self._incidence_angle
         del self._takeoff_angle
+        self.active = False
         self.__class__ = Marker
 
     def hoover_message(self):
