@@ -2,7 +2,9 @@
 #
 # The Pyrocko Developers, 21st Century
 # ---|P------/S----------~Lg----------
-'''Effective seismological trace viewer.'''
+'''
+Effective seismological trace viewer.
+'''
 from __future__ import absolute_import
 
 import os
@@ -49,13 +51,17 @@ def extend_paths(paths):
 
 
 def snuffle(pile=None, **kwargs):
-    '''View pile in a snuffler window.
+    '''
+    View pile in a snuffler window.
 
     :param pile: :py:class:`pile.Pile` object to be visualized
     :param stations: list of `pyrocko.model.Station` objects or ``None``
     :param events: list of `pyrocko.model.Event` objects or ``None``
     :param markers: list of `pyrocko.gui.util.Marker` objects or ``None``
     :param ntracks: float, number of tracks to be shown initially (default: 12)
+    :param marker_editor_sortable: bool, whether to allow sorting in marker
+        table (default True). Disabling this will give better performance
+        when working with many markers.
     :param follow: time interval (in seconds) for real time follow mode or
         ``None``
     :param controls: bool, whether to show the main controls (default:
@@ -259,6 +265,22 @@ def snuffler_from_commandline(args=None):
         metavar='N',
         help='initially use N waveform tracks in viewer [default: %default]')
 
+    parser.add_option(
+        '--disable-marker-sorting',
+        action='store_false',
+        dest='marker_editor_sortable',
+        default=True,
+        help='disable sorting in marker table for improved performance with '
+             '100000+ markers')
+
+    parser.add_option(
+        '--hptime',
+        choices=('on', 'off', 'config'),
+        dest='hp_time',
+        default='config',
+        metavar='on|off|config',
+        help='set high precision time mode [default: %default]')
+
     parser.add_option(
         '--opengl',
         dest='opengl',
@@ -294,6 +316,9 @@ def snuffler_from_commandline(args=None):
     else:
         util.setup_logging('snuffler', 'warning')
 
+    if options.hp_time in ('on', 'off'):
+        util.use_high_precision_time(options.hp_time == 'on')
+
     if options.gui_toolkit_qt4:
         config.override_gui_toolkit = 'qt4'
 
@@ -324,6 +349,7 @@ def snuffler_from_commandline(args=None):
         events=events,
         markers=markers,
         ntracks=options.ntracks,
+        marker_editor_sortable=options.marker_editor_sortable,
         follow=options.follow,
         controls=True,
         opengl=options.opengl,
