@@ -16,7 +16,7 @@ from pyrocko.guts import Object, Int, String, Timestamp
 
 from . import io_common
 
-logger = logging.getLogger('pyrocko.io.datacube')
+logger = logging.getLogger(__name__)
 
 N_GPS_TAGS_WANTED = 200  # must match definition in datacube_ext.c
 
@@ -90,10 +90,12 @@ def analyse_gps_tags(header, gps_tags, offset, nsamples):
 
     xok = num.abs(dtdt - 1.0) < 0.00001
 
-    ok[0] = False
-    ok[1:n] &= xok
-    ok[0:n-1] &= xok
-    ok[n-1] = False
+    if ok.size >= 1:
+
+        ok[0] = False
+        ok[1:n] &= xok
+        ok[0:n-1] &= xok
+        ok[n-1] = False
 
     ipos = ipos[ok]
     t = t[ok]
@@ -143,7 +145,7 @@ def analyse_gps_tags(header, gps_tags, offset, nsamples):
             icontrol = num.array(
                 [x[0] for x in control_points], dtype=num.int64)
             tcontrol = num.array(
-                [x[1] for x in control_points], dtype=num.float)
+                [x[1] for x in control_points], dtype=float)
             # robust against steps:
             slope = num.median(
                 (tcontrol[1:] - tcontrol[:-1])
@@ -159,7 +161,7 @@ def analyse_gps_tags(header, gps_tags, offset, nsamples):
             control_points.append((offset + nsamples - 1, tmax))
 
         icontrol = num.array([x[0] for x in control_points], dtype=num.int64)
-        tcontrol = num.array([x[1] for x in control_points], dtype=num.float)
+        tcontrol = num.array([x[1] for x in control_points], dtype=float)
 
         return tmin, tmax, icontrol, tcontrol, ok
 
@@ -180,6 +182,126 @@ def analyse_gps_tags(header, gps_tags, offset, nsamples):
         return tmin, tmax, icontrol, tcontrol, None
 
 
+def plot_gnss_location_timeline(fns):
+    from matplotlib import pyplot as plt
+    from pyrocko.orthodrome import latlon_to_ne_numpy
+    not_ = num.logical_not
+    h = 3600.
+
+    fig = plt.figure()
+
+    axes = []
+    for i in range(4):
+        axes.append(
+            fig.add_subplot(4, 1, i+1, sharex=axes[-1] if axes else None))
+
+    background_colors = [
+        color('aluminium1'),
+        color('aluminium2')]
+
+    tref = None
+    for ifn, fn in enumerate(fns):
+        header, gps_tags, nsamples = get_time_infos(fn)
+        _, t, fix, nsvs, lats, lons, elevations, _ = gps_tags
+
+        fix = fix.astype(bool)
+
+        if t.size < 2:
+            logger.warning('Need at least 2 gps tags for plotting: %s' % fn)
+
+        if tref is None:
+            tref = util.day_start(t[0])
+            lat, lon, elevation = coordinates_from_gps(gps_tags)
+
+        norths, easts = latlon_to_ne_numpy(lat, lon, lats, lons)
+
+        for ax, data in zip(axes, (norths, easts, elevations, nsvs)):
+
+            tspan = t[num.array([0, -1])]
+
+            ax.axvspan(*((tspan - tref) / h), color=background_colors[ifn % 2])
+            med = num.median(data)
+            ax.plot(
+                (tspan - tref) / h,
+                [med, med],
+                ls='--',
+                c='k',
+                lw=3,
+                alpha=0.5)
+
+            ax.plot(
+                (t[not_(fix)] - tref) / h, data[not_(fix)], 'o',
+                ms=1.5,
+                mew=0,
+                color=color('scarletred2'))
+
+            ax.plot(
+                (t[fix] - tref) / h, data[fix], 'o',
+                ms=1.5,
+                mew=0,
+                color=color('aluminium6'))
+
+    for ax in axes:
+        ax.grid(alpha=.3)
+
+    ax_lat, ax_lon, ax_elev, ax_nsv = axes
+
+    ax_lat.set_ylabel('Northing [m]')
+    ax_lon.set_ylabel('Easting [m]')
+    ax_elev.set_ylabel('Elevation [m]')
+    ax_nsv.set_ylabel('Number of Satellites')
+
+    ax_lat.get_xaxis().set_tick_params(labelbottom=False)
+    ax_lon.get_xaxis().set_tick_params(labelbottom=False)
+    ax_nsv.set_xlabel(
+        'Hours after %s' % util.time_to_str(tref, format='%Y-%m-%d'))
+
+    fig.suptitle(
+        u'Lat: %.5f\u00b0 Lon: %.5f\u00b0 Elevation: %g m' % (
+            lat, lon, elevation))
+
+    plt.show()
+
+
+def coordinates_from_gps(gps_tags):
+    ipos, t, fix, nsvs, lats, lons, elevations, temps = gps_tags
+    return tuple(num.median(x) for x in (lats, lons, elevations))
+
+
+def extract_stations(fns):
+    import io
+    import sys
+    from pyrocko.model import Station
+    from pyrocko.guts import dump_all
+
+    stations = {}
+
+    for fn in fns:
+        sta_name = os.path.splitext(fn)[1].lstrip('.')
+        if sta_name in stations:
+            logger.warning('Cube %s already in list!', sta_name)
+            continue
+
+        header, gps_tags, nsamples = get_time_infos(fn)
+
+        lat, lon, elevation = coordinates_from_gps(gps_tags)
+
+        sta = Station(
+            network='',
+            station=sta_name,
+            name=sta_name,
+            location='',
+            lat=lat,
+            lon=lon,
+            elevation=elevation)
+
+        stations[sta_name] = sta
+
+    f = io.BytesIO()
+    dump_all(stations.values(), stream=f)
+    sys.stdout.write(f.getvalue().decode())
+
+
 def plot_timeline(fns):
     from matplotlib import pyplot as plt
 
@@ -439,7 +561,7 @@ def get_extended_timing_context(fn):
             if num.sum(gps_tags[2]) > 0:
                 break
 
-    ipos, t, fix, nsvs = [num.concatenate(x) for x in zip(*aggregated)]
+    ipos, t, fix, nsvs = [num.concatenate(x) for x in zip(*aggregated)][:4]
 
 #    return ipos, t, fix, nsvs, header, ioff, nsamples_total
     return ipos, t, fix, nsvs, header, 0, nsamples_base
@@ -495,7 +617,7 @@ def iload(fn, load_data=True, interpolation='sinc'):
 
     leaps = num.array(
         [x[0] + util.gps_utc_offset(x[0]) for x in util.read_leap_seconds2()],
-        dtype=num.float)
+        dtype=float)
 
     if load_data and icontrol is not None:
         ncontrol_this = num.sum(
@@ -513,11 +635,11 @@ def iload(fn, load_data=True, interpolation='sinc'):
 
             if interpolation == 'sinc' and icontrol is not None:
 
-                ydata = num.empty(nsamples_ip, dtype=num.float)
+                ydata = num.empty(nsamples_ip, dtype=float)
                 try:
                     signal_ext.antidrift(
                         icontrol, tcontrol,
-                        arr.astype(num.float), tmin_ip, deltat, ydata)
+                        arr.astype(float), tmin_ip, deltat, ydata)
 
                 except signal_ext.Error as e:
                     e = DataCubeError(str(e))
@@ -598,9 +720,21 @@ def detect(first512):
 
 
 if __name__ == '__main__':
-    import sys
-    fns = sys.argv[1:]
-    if len(fns) > 1:
-        plot_timeline(fns)
-    else:
-        plot_timeline(fns[0])
+    import argparse
+    parser = argparse.ArgumentParser(description='Datacube reader')
+
+    parser.add_argument(
+        'action', choices=['timeline', 'gnss', 'stations'],
+        help='Action')
+    parser.add_argument(
+        'files', nargs='+')
+
+    args = parser.parse_args()
+    if args.action == 'timeline':
+        plot_timeline(args.files)
+
+    elif args.action == 'gnss':
+        plot_gnss_location_timeline(args.files)
+
+    elif args.action == 'stations':
+        extract_stations(args.files)
