@@ -56,11 +56,12 @@ class Tag(StringPattern):
 
 
 class Event(Location):
-    '''Seismic event representation
+    '''
+    Representation of a seismic event.
 
     :param lat: latitude of hypocenter (default 0.0)
     :param lon: longitude of hypocenter (default 0.0)
-    :param time: origin time as float in seconds after '1970-01-01 00:00:00
+    :param time: origin time system timestamp
     :param name: event identifier as string (optional)
     :param depth: source depth (optional)
     :param magnitude: magnitude of event (optional)
@@ -74,7 +75,7 @@ class Event(Location):
         Keys must be strings, values must be YAML serializable.
     '''
 
-    time = Timestamp.T(default=util.str_to_time('1970-01-01 00:00:00'))
+    time = Timestamp.T(default=Timestamp.D('1970-01-01 00:00:00'))
     depth = Float.T(optional=True)
     name = String.T(default='', optional=True, yamlstyle="'")
     magnitude = Float.T(optional=True)
@@ -325,10 +326,10 @@ class Event(Location):
 
     def get_hash(self):
         e = self
-        if isinstance(e.time, util.hpfloat):
-            stime = util.time_to_str(e.time, format='%Y-%m-%d %H:%M:%S.6FRAC')
-        else:
+        if isinstance(e.time, float):
             stime = util.time_to_str(e.time, format='%Y-%m-%d %H:%M:%S.3FRAC')
+        else:
+            stime = util.time_to_str(e.time, format='%Y-%m-%d %H:%M:%S.6FRAC')
 
         s = float_or_none_to_str
 
@@ -384,7 +385,8 @@ def detect_format(filename):
 
 
 def load_events(filename, format='detect'):
-    '''Read events file.
+    '''
+    Read events file.
 
     :param filename: name of file as str
     :param format: file format: ``'detect'``, ``'basic'``, or ``'yaml'``
@@ -422,7 +424,8 @@ def load_one_event(filename, format='detect'):
 
 
 def dump_events(events, filename=None, stream=None, format='basic'):
-    '''Write events file.
+    '''
+    Write events file.
 
     :param events: list of :py:class:`Event` objects
     :param filename: name of file as str
@@ -450,7 +453,7 @@ def load_kps_event_list(filename):
         if len(toks) < 7:
             continue
 
-        tim = util.ctimegm(toks[0]+' '+toks[1])
+        tim = util.to_time_float(util.ctimegm(toks[0]+' '+toks[1]))
         lat, lon, depth, magnitude = [float(x) for x in toks[2:6]]
         duration = float(toks[10])
         region = toks[-1]
