@@ -26,6 +26,7 @@ from . import config
 from .trace import degapper
 
 
+is_windows = sys.platform.startswith('win')
 show_progress_force_off = False
 version_salt = 'v1-'
 
@@ -79,7 +80,7 @@ def avl_remove_exact(avltree, element):
     for i in range(ilo, ihi):
         if avltree[i] is element:
             avltree.remove_at(i)
-            return
+            return i
 
     raise ValueError(
         'avl_remove_exact(avltree, element): element not in avltree')
@@ -113,6 +114,12 @@ def get_dummy(key):
     return g_dummys[key]
 
 
+class TooMany(Exception):
+    def __init__(self, n):
+        Exception.__init__(self)
+        self.n = n
+
+
 class Sorted(object):
     def __init__(self, values=[], key=None):
         self._set_key(key)
@@ -137,7 +144,10 @@ class Sorted(object):
         self._avl.insert(value)
 
     def remove(self, value):
-        avl_remove_exact(self._avl, value)
+        return avl_remove_exact(self._avl, value)
+
+    def remove_at(self, i):
+        return self._avl.remove_at(i)
 
     def insert_many(self, values):
         for value in values:
@@ -155,6 +165,22 @@ class Sorted(object):
         ilo, ihi = self._avl.span(omin, omax)
         return self._avl[ilo:ihi]
 
+    def with_key_in_limited(self, kmin, kmax, nmax):
+        omin, omax = self._dummy(kmin), self._dummy(kmax)
+        ilo, ihi = self._avl.span(omin, omax)
+        if ihi - ilo > nmax:
+            raise TooMany(ihi - ilo)
+
+        return self._avl[ilo:ihi]
+
+    def index(self, value):
+        ilo, ihi = self._avl.span(value)
+        for i in range(ilo, ihi):
+            if self._avl[i] is value:
+                return i
+
+        raise ValueError('element is not in avl tree')
+
     def min(self):
         return self._avl.min()
 
@@ -164,9 +190,13 @@ class Sorted(object):
     def __len__(self):
         return len(self._avl)
 
+    def __getitem__(self, i):
+        return self._avl[i]
+
 
 class TracesFileCache(object):
-    '''Manages trace metainformation cache.
+    '''
+    Manages trace metainformation cache.
 
     For each directory with files containing traces, one cache file is
     maintained to hold the trace metainformation of all files which are
@@ -176,10 +206,10 @@ class TracesFileCache(object):
     caches = {}
 
     def __init__(self, cachedir):
-        '''Create new cache.
+        '''
+        Create new cache.
 
         :param cachedir: directory to hold the cache files.
-
         '''
 
         self.cachedir = cachedir
@@ -188,13 +218,13 @@ class TracesFileCache(object):
         util.ensuredir(self.cachedir)
 
     def get(self, abspath):
-        '''Try to get an item from the cache.
+        '''
+        Try to get an item from the cache.
 
         :param abspath: absolute path of the object to retrieve
 
         :returns: a stored object is returned or None if nothing could be
             found.
-
         '''
 
         dircache = self._get_dircache_for(abspath)
@@ -203,7 +233,8 @@ class TracesFileCache(object):
         return None
 
     def put(self, abspath, tfile):
-        '''Put an item into the cache.
+        '''
+        Put an item into the cache.
 
         :param abspath: absolute path of the object to be stored
         :param tfile: object to be stored
@@ -216,7 +247,9 @@ class TracesFileCache(object):
         self.modified.add(cachepath)
 
     def dump_modified(self):
-        '''Save any modifications to disk.'''
+        '''
+        Save any modifications to disk.
+        '''
 
         for cachepath in self.modified:
             self._dump_dircache(self.dircaches[cachepath], cachepath)
@@ -225,7 +258,9 @@ class TracesFileCache(object):
         self.modified = set()
 
     def clean(self):
-        '''Weed out missing files from the disk caches.'''
+        '''
+        Weed out missing files from the disk caches.
+        '''
 
         self.dump_modified()
 
@@ -260,6 +295,8 @@ class TracesFileCache(object):
             if not os.path.isfile(fn):
                 del cache[fn]
 
+        time_float = util.get_time_float()
+
         for v in cache.values():
             v.trees_from_content(v.traces)
             for tr in v.traces:
@@ -274,6 +311,9 @@ class TracesFileCache(object):
                         str(tr.location),
                         str(tr.channel))
 
+                tr.tmin = time_float(tr.tmin)
+                tr.tmax = time_float(tr.tmax)
+
             v.data_use_count = 0
             v.data_loaded = False
             v.fix_unicode_codes()
@@ -314,11 +354,17 @@ class TracesFileCache(object):
         with open(tmpfn, 'wb') as f:
             pickle.dump(cache_copy, f, protocol=2)
 
+        if is_windows and os.path.exists(cachefilename):
+            # windows doesn't allow to rename over existing file
+            os.unlink(cachefilename)
+
         os.rename(tmpfn, cachefilename)
 
 
 def get_cache(cachedir):
-    '''Get global TracesFileCache object for given directory.'''
+    '''
+    Get global TracesFileCache object for given directory.
+    '''
     if cachedir not in TracesFileCache.caches:
         TracesFileCache.caches[cachedir] = TracesFileCache(cachedir)
 
@@ -466,7 +512,8 @@ def tlen(x):
 
 class TracesGroup(object):
 
-    '''Trace container base class.
+    '''
+    Trace container base class.
 
     Base class for Pile, SubPile, and TracesFile, i.e. anything containing
     a collection of several traces. A TracesGroup object maintains lookup sets
@@ -606,7 +653,8 @@ class TracesGroup(object):
             self.parent.remove(content)
 
     def relevant(self, tmin, tmax, group_selector=None, trace_selector=None):
-        '''Return list of :py:class:`pyrocko.trace.Trace` objects where given
+        '''
+        Return list of :py:class:`pyrocko.trace.Trace` objects where given
         arguments ``tmin`` and ``tmax`` match.
 
         :param tmin: start time
@@ -664,8 +712,10 @@ class TracesGroup(object):
 
 class MemTracesFile(TracesGroup):
 
-    '''This is needed to make traces without an actual disc file to be inserted
-    into a Pile.'''
+    '''
+    This is needed to make traces without an actual disc file to be inserted
+    into a Pile.
+    '''
 
     def __init__(self, parent, traces):
         TracesGroup.__init__(self, parent)
@@ -967,8 +1017,49 @@ class SubPile(TracesGroup):
         return s
 
 
+class Batch(object):
+    '''
+    Batch of waveforms from window wise data extraction.
+
+    Encapsulates state and results yielded for each window in window wise
+    waveform extraction with the :py:meth:`Pile.chopper` method (when the
+    `style='batch'` keyword argument set).
+
+    *Attributes:*
+
+    .. py:attribute:: tmin
+
+        Start of this time window.
+
+    .. py:attribute:: tmax
+
+        End of this time window.
+
+    .. py:attribute:: i
+
+        Index of this time window in sequence.
+
+    .. py:attribute:: n
+
+        Total number of time windows in sequence.
+
+    .. py:attribute:: traces
+
+        Extracted waveforms for this time window.
+    '''
+
+    def __init__(self, tmin, tmax, i, n, traces):
+        self.tmin = tmin
+        self.tmax = tmax
+        self.i = i
+        self.n = n
+        self.traces = traces
+
+
 class Pile(TracesGroup):
-    '''Waveform archive lookup, data loading and caching infrastructure.'''
+    '''
+    Waveform archive lookup, data loading and caching infrastructure.
+    '''
 
     def __init__(self):
         TracesGroup.__init__(self, None)
@@ -1140,7 +1231,8 @@ class Pile(TracesGroup):
             group_selector=None, trace_selector=None,
             want_incomplete=True, degap=True, maxgap=5, maxlap=None,
             keep_current_files_open=False, accessor_id=None,
-            snap=(round, round), include_last=False, load_data=True):
+            snap=(round, round), include_last=False, load_data=True,
+            style=None):
 
         '''
         Get iterator for shifting window wise data extraction from waveform
@@ -1176,8 +1268,11 @@ class Pile(TracesGroup):
         :param load_data: whether to load the waveform data. If set to
             ``False``, traces with no data samples, but with correct
             meta-information are returned
-        :returns: itererator yielding a list of :py:class:`pyrocko.trace.Trace`
-            objects for every extracted time window
+        :param style: set to ``'batch'`` to yield waveforms and information
+            about the chopper state as :py:class:`Batch` objects. By default
+            lists of :py:class:`pyrocko.trace.Trace` objects are yielded.
+        :returns: iterator providing extracted waveforms for each extracted
+            window. See ``style`` argument for details.
         '''
         if tmin is None:
             if self.tmin is None:
@@ -1202,13 +1297,15 @@ class Pile(TracesGroup):
 
         open_files = self.open_files[accessor_id]
 
-        iwin = 0
-        while True:
+        eps = tinc * 1e-6
+        if tinc != 0.0:
+            nwin = int(((tmax - eps) - tmin) / tinc) + 1
+        else:
+            nwin = 1
+
+        for iwin in range(nwin):
             chopped = []
             wmin, wmax = tmin+iwin*tinc, min(tmin+(iwin+1)*tinc, tmax)
-            eps = tinc*1e-6
-            if wmin >= tmax-eps:
-                break
 
             chopped, used_files = self.chop(
                 wmin-tpad, wmax+tpad, group_selector, trace_selector, snap,
@@ -1224,7 +1321,16 @@ class Pile(TracesGroup):
                 chopped, degap, maxgap, maxlap, want_incomplete, wmax, wmin,
                 tpad)
 
-            yield processed
+            if style == 'batch':
+                yield Batch(
+                    tmin=wmin,
+                    tmax=wmax,
+                    i=iwin,
+                    n=nwin,
+                    traces=processed)
+
+            else:
+                yield processed
 
             unused_files = open_files - used_files
 
@@ -1233,8 +1339,6 @@ class Pile(TracesGroup):
                 file.drop_data()
                 open_files.remove(file)
 
-            iwin += 1
-
         if not keep_current_files_open:
             while open_files:
                 file = open_files.pop()
@@ -1314,7 +1418,8 @@ class Pile(TracesGroup):
             group_selector=None,
             trace_selector=None):
 
-        '''Iterate over all traces in pile.
+        '''
+        Iterate over all traces in pile.
 
         :param load_data: whether to load the waveform data, by default empty
             traces are yielded
@@ -1386,7 +1491,8 @@ class Pile(TracesGroup):
         return s
 
     def snuffle(self, **kwargs):
-        '''Visualize it.
+        '''
+        Visualize it.
 
         :param stations: list of `pyrocko.model.Station` objects or ``None``
         :param events: list of `pyrocko.model.Event` objects or ``None``
@@ -1409,7 +1515,8 @@ def make_pile(
         fileformat='mseed',
         cachedirname=None, show_progress=True):
 
-    '''Create pile from given file and directory names.
+    '''
+    Create pile from given file and directory names.
 
     :param paths: filenames and/or directories to look for traces. If paths is
         ``None`` ``sys.argv[1:]`` is used.
@@ -1467,7 +1574,8 @@ class Injector(trace.States):
         self._forget_fixed = forget_fixed
 
     def set_fixation_length(self, length):
-        '''Set length after which the fixation method is called on buffer traces.
+        '''
+        Set length after which the fixation method is called on buffer traces.
 
         The length should be given in seconds. Give None to disable.
         '''
