@@ -245,7 +245,8 @@ class ScenarioGenerator(LocationGenerator):
         return lambda gen: [gen.get_time_range(self.get_sources())]
 
     def get_time_range(self):
-        ranges = num.array(self._get_time_ranges())
+        ranges = num.array(
+            self._get_time_ranges(), dtype=util.get_time_dtype())
         return ranges.min(), ranges.max()
 
     def _time_range_fill_defaults(self, tmin, tmax):
@@ -378,7 +379,8 @@ class ScenarioGenerator(LocationGenerator):
             cls, path,
             center_lat=None, center_lon=None, radius=None,
             targets=AVAILABLE_TARGETS, stationxml=None, force=False):
-        """Initialize a Scenario and create a ``scenario.yml``
+        '''
+        Initialize a Scenario and create a ``scenario.yml``
 
         :param path: Path to create the scenerio in
         :type path: str
@@ -399,7 +401,7 @@ class ScenarioGenerator(LocationGenerator):
         :type stationxml: str
         :returns: Scenario
         :rtype: :class:`pyrocko.scenario.ScenarioGenerator`
-        """
+        '''
         import os.path as op
 
         if op.exists(path) and not force:
