@@ -29,7 +29,7 @@ class Cell(object):
     def __init__(self, tree, index, f=None):
         self.tree = tree
         self.index = index
-        self.depths = num.log2(index).astype(num.int)
+        self.depths = num.log2(index).astype(int)
         self.bad = False
         self.children = []
         n = 2**self.depths
@@ -76,7 +76,7 @@ class Cell(object):
 
     def interpolate_many(self, x):
         if self.children:
-            result = num.empty(x.shape[0], dtype=num.float)
+            result = num.empty(x.shape[0], dtype=float)
             result[:] = None
             for cell in self.children:
                 indices = num.where(
@@ -110,12 +110,12 @@ class Cell(object):
 
                 return result
             else:
-                result = num.empty(x.shape[0], dtype=num.float)
+                result = num.empty(x.shape[0], dtype=float)
                 result[:] = None
                 return result
 
     def slice(self, x):
-        x = num.array(x, dtype=num.float)
+        x = num.array(x, dtype=float)
         x_mask = not_(num.isfinite(x))
         x_ = x.copy()
         x_[x_mask] = 0.0
@@ -141,7 +141,9 @@ class Cell(object):
             axes.plot(points[1], points[0], color=(0.1, 0.1, 0.0, 0.1))
 
     def check_holes(self):
-        ''' Check if :py:class:`Cell` or its' children contain NaNs'''
+        '''
+        Check if :py:class:`Cell` or its children contain NaNs.
+        '''
         if self.children:
             return any([child.check_holes() for child in self.children])
         else:
@@ -156,7 +158,7 @@ class Cell(object):
 
         npoints = coords[0].size * coords[1].size
         g = num.meshgrid(*coords[::-1])[::-1]
-        points = num.empty((npoints, self.tree.ndim), dtype=num.float)
+        points = num.empty((npoints, self.tree.ndim), dtype=float)
         for idim in range(self.tree.ndim):
             try:
                 idimout = dims.index(idim)
@@ -164,7 +166,7 @@ class Cell(object):
             except ValueError:
                 points[:, idim] = x[idim]
 
-        fi = num.empty((coords[0].size, coords[1].size), dtype=num.float)
+        fi = num.empty((coords[0].size, coords[1].size), dtype=float)
         fi_r = fi.ravel()
         fi_r[...] = self.interpolate_many(points)
 
@@ -186,7 +188,7 @@ class Cell(object):
         coords = num.linspace(xb[0], xb[1], 1+int((xb[1]-xb[0])/d))
 
         npoints = coords.size
-        points = num.empty((npoints, self.tree.ndim), dtype=num.float)
+        points = num.empty((npoints, self.tree.ndim), dtype=float)
         for idim in range(self.tree.ndim):
             if idim == dim:
                 points[:, idim] = coords
@@ -221,7 +223,8 @@ class SPTree(object):
     def __init__(self, f=None, ftol=None, xbounds=None, xtols=None,
                  filename=None, addargs=()):
 
-        '''Create n-dimensional space partitioning interpolator.
+        '''
+        Create n-dimensional space partitioning interpolator.
 
         :param f: callable function f(x) where x is a vector of size n
         :param ftol: target accuracy |f_interp(x) - f(x)| <= ftol
@@ -239,22 +242,22 @@ class SPTree(object):
             self.ncells = 0
             self.addargs = addargs
 
-            self.xbounds = num.asarray(xbounds, dtype=num.float)
+            self.xbounds = num.asarray(xbounds, dtype=float)
             assert self.xbounds.ndim == 2
             assert self.xbounds.shape[1] == 2
             self.ndim = self.xbounds.shape[0]
 
-            self.xtols = num.asarray(xtols, dtype=num.float)
+            self.xtols = num.asarray(xtols, dtype=float)
             assert self.xtols.ndim == 1 and self.xtols.size == self.ndim
 
             self.maxdepths = num.ceil(num.log2(
                 num.maximum(
                     1.0,
                     (self.xbounds[:, 1] - self.xbounds[:, 0]) / self.xtols)
-                )).astype(num.int)
+                )).astype(int)
 
             self.root = None
-            self.ones_int = num.ones(self.ndim, dtype=num.int)
+            self.ones_int = num.ones(self.ndim, dtype=int)
 
             cc = num.ix_(*[num.arange(3)]*self.ndim)
             w = num.zeros([3]*self.ndim + [self.ndim, 2])
@@ -352,7 +355,7 @@ class SPTree(object):
             self.f_values, tuple(float(xx) for xx in x), self.f, self.addargs)
 
     def interpolate(self, x):
-        x = num.asarray(x, dtype=num.float)
+        x = num.asarray(x, dtype=float)
         assert x.ndim == 1 and x.size == self.ndim
         if not all_(and_(self.xbounds[:, 0] <= x, x <= self.xbounds[:, 1])):
             raise OutOfBounds()
@@ -377,7 +380,7 @@ class SPTree(object):
 
         fis = cell.interpolate_many(xtestpoints)
         fes = num.array(
-            [self._f_cached(x) for x in xtestpoints], dtype=num.float)
+            [self._f_cached(x) for x in xtestpoints], dtype=float)
 
         iffes = num.isfinite(fes)
         iffis = num.isfinite(fis)
@@ -437,7 +440,9 @@ class SPTree(object):
             self._fill(child)
 
     def check_holes(self):
-        '''Check for NaNs in :py:class:`SPTree`'''
+        '''
+        Check for NaNs in :py:class:`SPTree`
+        '''
         return self.root.check_holes()
 
     def plot_2d(self, axes=None, x=None, dims=None):
@@ -447,7 +452,7 @@ class SPTree(object):
             x = num.zeros(self.ndim)
             x[-2:] = None
 
-        x = num.asarray(x, dtype=num.float)
+        x = num.asarray(x, dtype=float)
         if dims is None:
             dims = [i for (i, v) in enumerate(x) if not num.isfinite(v)]
 
@@ -472,7 +477,7 @@ class SPTree(object):
             x = num.zeros(self.ndim)
             x[-1:] = None
 
-        x = num.asarray(x, dtype=num.float)
+        x = num.asarray(x, dtype=float)
         if dims is None:
             dims = [i for (i, v) in enumerate(x) if not num.isfinite(v)]
 
@@ -509,7 +514,7 @@ def nditer_outer(x):
 
     return num.nditer(
         x,
-        op_axes=(num.identity(len(x_), dtype=num.int)-1).tolist() + add)
+        op_axes=(num.identity(len(x_), dtype=int)-1).tolist() + add)
 
 
 if __name__ == '__main__':
