@@ -2,7 +2,64 @@
 #
 # The Pyrocko Developers, 21st Century
 # ---|P------/S----------~Lg----------
-'''Utility functions for Pyrocko.'''
+'''
+Utility functions for Pyrocko.
+
+.. _time-handling-mode:
+
+High precision time handling mode
+.................................
+
+Pyrocko can treat timestamps either as standard double precision (64 bit)
+floating point values, or as high precision float (:py:class:`numpy.float128`
+or :py:class:`numpy.float96`, whichever is available), aliased here as
+:py:class:`pyrocko.util.hpfloat`. High precision time stamps are required when
+handling data with sub-millisecond precision, i.e. kHz/MHz data streams and
+event catalogs derived from such data.
+
+Not all functions in Pyrocko and in programs depending on Pyrocko may work
+correctly with high precision times. Therefore, Pyrocko's high precision time
+handling mode has to be actively activated by user config, command line option
+or enforced within a certain script/program.
+
+The default high precision time handling mode can be configured globally with
+the user config variable
+:py:gattr:`~pyrocko.config.Config.use_high_precision_time`. Calling the
+function :py:func:`use_high_precision_time` overrides the default from the
+config file. This function may be called at startup of a program/script
+requiring a specific time handling mode.
+
+To create a valid time stamp for use in Pyrocko (e.g. in
+:py:class:`~pyrocko.model.Event` or :py:class:`~pyrocko.trace.Trace` objects),
+use:
+
+.. code-block :: python
+
+    import time
+    from pyrocko import util
+
+    # By default using mode selected in user config, override with:
+    # util.use_high_precision_time(True)   # force high precision mode
+    # util.use_high_precision_time(False)  # force low precision mode
+
+    t1 = util.str_to_time('2020-08-27 10:22:00')
+    t2 = util.str_to_time('2020-08-27 10:22:00.111222')
+    t3 = util.to_time_float(time.time())
+
+    # To get the appropriate float class, use:
+
+    time_float = util.get_time_float()
+    #  -> float, numpy.float128 or numpy.float96
+    [isinstance(t, time_float) for t in [t1, t2, t3]]
+    #  -> [True, True, True]
+
+    # Shortcut:
+    util.check_time_class(t1)
+
+Module content
+..............
+'''
+
 from __future__ import division, print_function
 
 import time
@@ -13,27 +70,29 @@ import re
 import calendar
 import math
 import fnmatch
-import fcntl
-import shlex
+try:
+    import fcntl
+except ImportError:
+    fcntl = None
 import optparse
 import os.path as op
-import platform
 import errno
 
 import numpy as num
 from scipy import signal
+import pyrocko
 from pyrocko import dummy_progressbar
 
 try:
     from urllib.parse import urlencode, quote, unquote  # noqa
     from urllib.request import (
-        Request, build_opener, HTTPDigestAuthHandler, urlopen)  # noqa
+        Request, build_opener, HTTPDigestAuthHandler, urlopen as _urlopen)  # noqa
     from urllib.error import HTTPError, URLError  # noqa
 
 except ImportError:
     from urllib import urlencode, quote, unquote # noqa
     from urllib2 import (Request, build_opener, HTTPDigestAuthHandler,   # noqa
-                         HTTPError, URLError, urlopen)  # noqa
+                         HTTPError, URLError, urlopen as _urlopen)  # noqa
 
 
 class URLErrorSSL(URLError):
@@ -60,6 +119,17 @@ def urlopen_ssl_check(*args, **kwargs):
             raise
 
 
+def urlopen(*args, **kwargs):
+    if 'cafile' not in kwargs:
+        try:
+            import certifi
+            kwargs['cafile'] = certifi.where()
+        except ImportError:
+            pass
+
+    return _urlopen(*args, **kwargs)
+
+
 try:
     long
 except NameError:
@@ -69,9 +139,9 @@ except NameError:
 force_dummy_progressbar = False
 
 
-if platform.system() != 'Darwin':
+try:
     from pyrocko import util_ext
-else:
+except ImportError:
     util_ext = None
 
 
@@ -343,15 +413,181 @@ def download_dir(
         **kwargs)
 
 
+class HPFloatUnavailable(Exception):
+    pass
+
+
+class dummy_hpfloat(object):
+    def __init__(self, *args, **kwargs):
+        raise HPFloatUnavailable(
+            'NumPy lacks support for float128 or float96 data type on this '
+            'platform.')
+
+
 if hasattr(num, 'float128'):
     hpfloat = num.float128
 elif hasattr(num, 'float96'):
     hpfloat = num.float96
 else:
-    def hpfloat(x):
-        raise Exception(
-            'NumPy lacks support for float128 or float96 data type on this '
-            'platform.')
+    hpfloat = dummy_hpfloat
+
+
+g_time_float = None
+g_time_dtype = None
+
+
+class TimeFloatSettingError(Exception):
+    pass
+
+
+def use_high_precision_time(enabled):
+    '''
+    Globally force a specific time handling mode.
+
+    See :ref:`High precision time handling mode <time-handling-mode>`.
+
+    :param enabled: enable/disable use of high precision time type
+    :type enabled: bool
+
+    This function should be called before handling/reading any time data.
+    It can only be called once.
+
+    Special attention is required when using multiprocessing on a platform
+    which does not use fork under the hood. In such cases, the desired setting
+    must be set also in the subprocess.
+    '''
+    _setup_high_precision_time_mode(enabled_app=enabled)
+
+
+def _setup_high_precision_time_mode(enabled_app=False):
+    global g_time_float
+    global g_time_dtype
+
+    if not (g_time_float is None and g_time_dtype is None):
+        raise TimeFloatSettingError(
+            'Cannot set time handling mode: too late, it has already been '
+            'fixed by an earlier call.')
+
+    from pyrocko import config
+
+    conf = config.config()
+    enabled_config = conf.use_high_precision_time
+
+    enabled_env = os.environ.get('PYROCKO_USE_HIGH_PRECISION_TIME', None)
+    if enabled_env is not None:
+        try:
+            enabled_env = int(enabled_env) == 1
+        except ValueError:
+            raise TimeFloatSettingError(
+                'Environment variable PYROCKO_USE_HIGH_PRECISION_TIME '
+                'should be set to 0 or 1.')
+
+    enabled = enabled_config
+    mode_from = 'config variable `use_high_precision_time`'
+    notify = enabled
+
+    if enabled_env is not None:
+        if enabled_env != enabled:
+            notify = True
+        enabled = enabled_env
+        mode_from = 'environment variable `PYROCKO_USE_HIGH_PRECISION_TIME`'
+
+    if enabled_app is not None:
+        if enabled_app != enabled:
+            notify = True
+        enabled = enabled_app
+        mode_from = 'application override'
+
+    logger.debug('''
+Pyrocko high precision time mode selection (latter override earlier):
+    config: %s
+    env: %s
+    app: %s
+     -> enabled: %s'''.lstrip() % (
+         enabled_config, enabled_env, enabled_app, enabled))
+
+    if notify:
+        logger.info('Pyrocko high precision time mode %s by %s.' % (
+            'activated' if enabled else 'deactivated',
+            mode_from))
+
+    if enabled:
+        g_time_float = hpfloat
+        g_time_dtype = hpfloat
+    else:
+        g_time_float = float
+        g_time_dtype = num.float64
+
+
+def get_time_float():
+    '''
+    Get the effective float class for timestamps.
+
+    See :ref:`High precision time handling mode <time-handling-mode>`.
+
+    :returns: :py:class:`float` or :py:class:`hpfloat`, depending on the
+        current time handling mode
+    '''
+    global g_time_float
+
+    if g_time_float is None:
+        _setup_high_precision_time_mode()
+
+    return g_time_float
+
+
+def get_time_dtype():
+    '''
+    Get effective NumPy float class to handle timestamps.
+
+    See :ref:`High precision time handling mode <time-handling-mode>`.
+    '''
+
+    global g_time_dtype
+
+    if g_time_dtype is None:
+        _setup_high_precision_time_mode()
+
+    return g_time_dtype
+
+
+def to_time_float(t):
+    '''
+    Convert float to valid time stamp in the current time handling mode.
+
+    See :ref:`High precision time handling mode <time-handling-mode>`.
+    '''
+    return get_time_float()(t)
+
+
+class TimestampTypeError(ValueError):
+    pass
+
+
+def check_time_class(t, error='raise'):
+    '''
+    Type-check variable against current time handling mode.
+
+    See :ref:`High precision time handling mode <time-handling-mode>`.
+    '''
+
+    if t == 0.0:
+        return
+
+    if not isinstance(t, get_time_float()):
+        message = (
+            'Timestamp %g is of type %s but should be of type %s with '
+            'Pyrocko\'s currently selected time handling mode.\n\n'
+            'See https://pyrocko.org/docs/current/library/reference/util.html'
+            '#high-precision-time-handling-mode' % (
+                t, type(t), get_time_float()))
+
+        if error == 'raise':
+            raise TimestampTypeError(message)
+        elif error == 'warn':
+            logger.warn(message)
+        else:
+            assert False
 
 
 class Stopwatch(object):
@@ -525,7 +761,7 @@ class ArangeError(Exception):
     pass
 
 
-def arange2(start, stop, step, dtype=num.float, epsilon=1e-6, error='raise'):
+def arange2(start, stop, step, dtype=float, epsilon=1e-6, error='raise'):
     '''
     Return evenly spaced numbers over a specified interval.
 
@@ -661,7 +897,7 @@ def diff_fd_1d_4o(dt, data):
     '''
     import scipy.signal
 
-    ddata = num.empty_like(data, dtype=num.float)
+    ddata = num.empty_like(data, dtype=float)
 
     if data.size >= 5:
         ddata[2:-2] = scipy.signal.lfilter(
@@ -713,7 +949,7 @@ def diff_fd_2d_4o(dt, data):
     '''
     import scipy.signal
 
-    ddata = num.empty_like(data, dtype=num.float)
+    ddata = num.empty_like(data, dtype=float)
 
     if data.size >= 5:
         ddata[2:-2] = scipy.signal.lfilter(
@@ -742,7 +978,7 @@ def diff_fd_2d_2o(dt, data):
     '''
     import scipy.signal
 
-    ddata = num.empty_like(data, dtype=num.float)
+    ddata = num.empty_like(data, dtype=float)
 
     if data.size >= 3:
         ddata[1:-1] = scipy.signal.lfilter(
@@ -854,7 +1090,7 @@ def decimate(x, q, n=None, ftype='iir', zi=None, ioff=0):
     b, a, n = decimate_coeffs(q, n, ftype)
 
     if zi is None or zi is True:
-        zi_ = num.zeros(max(len(a), len(b))-1, dtype=num.float)
+        zi_ = num.zeros(max(len(a), len(b))-1, dtype=float)
     else:
         zi_ = zi
 
@@ -933,7 +1169,7 @@ def zfmt(n):
 
 def _year_to_time(year):
     tt = (year, 1, 1, 0, 0, 0)
-    return calendar.timegm(tt)
+    return to_time_float(calendar.timegm(tt))
 
 
 def _working_year(year):
@@ -950,16 +1186,18 @@ def _working_year(year):
         if s != s2:
             return False
 
+        t3 = str_to_time(s2, format='%Y-%m-%d %H:%M:%S')
+        s3 = time_to_str(t3, format='%Y-%m-%d %H:%M:%S')
+        if s3 != s2:
+            return False
+
     except Exception:
         return False
 
     return True
 
 
-g_working_system_time_range = None
-
-
-def get_working_system_time_range():
+def working_system_time_range(year_min_lim=None, year_max_lim=None):
     '''
     Check time range supported by the systems's time conversion functions.
 
@@ -970,33 +1208,51 @@ def get_working_system_time_range():
     :returns: ``(tmin, tmax, year_min, year_max)``
     '''
 
+    year0 = 2000
+    year_min = year0
+    year_max = year0
+
+    itests = list(range(101))
+    for i in range(19):
+        itests.append(200 + i*100)
+
+    for i in itests:
+        year = year0 - i
+        if year_min_lim is not None and year < year_min_lim:
+            year_min = year_min_lim
+            break
+        elif not _working_year(year):
+            break
+        else:
+            year_min = year
+
+    for i in itests:
+        year = year0 + i
+        if year_max_lim is not None and year > year_max_lim:
+            year_max = year_max_lim
+            break
+        elif not _working_year(year + 1):
+            break
+        else:
+            year_max = year
+
+    return (
+        _year_to_time(year_min),
+        _year_to_time(year_max),
+        year_min, year_max)
+
+
+g_working_system_time_range = None
+
+
+def get_working_system_time_range():
+    '''
+    Caching variant of :py:func:`working_system_time_range`.
+    '''
+
     global g_working_system_time_range
-
     if g_working_system_time_range is None:
-        year0 = 2000
-        year_min = year0
-        year_max = year0
-
-        itests = list(range(101))
-        for i in range(19):
-            itests.append(200 + i*100)
-
-        for i in itests:
-            if not _working_year(year0 - i):
-                break
-            else:
-                year_min = year0 - i
-
-        for i in itests:
-            if not _working_year(year0 + i + 1):
-                break
-            else:
-                year_max = year0 + i
-
-        g_working_system_time_range = (
-            _year_to_time(year_min),
-            _year_to_time(year_max),
-            year_min, year_max)
+        g_working_system_time_range = working_system_time_range()
 
     return g_working_system_time_range
 
@@ -1016,6 +1272,20 @@ def julian_day_of_year(timestamp):
     return time.gmtime(int(timestamp)).tm_yday
 
 
+def hour_start(timestamp):
+    '''
+    Get beginning of hour for any point in time.
+
+    :param timestamp: time instant as system timestamp (in seconds)
+
+    :returns: instant of hour start as system timestamp
+    '''
+
+    tt = time.gmtime(int(timestamp))
+    tts = tt[0:4] + (0, 0)
+    return to_time_float(calendar.timegm(tts))
+
+
 def day_start(timestamp):
     '''
     Get beginning of day for any point in time.
@@ -1026,8 +1296,8 @@ def day_start(timestamp):
     '''
 
     tt = time.gmtime(int(timestamp))
-    tts = tt[0:3] + (0, 0, 0) + tt[6:9]
-    return calendar.timegm(tts)
+    tts = tt[0:3] + (0, 0, 0)
+    return to_time_float(calendar.timegm(tts))
 
 
 def month_start(timestamp):
@@ -1040,8 +1310,8 @@ def month_start(timestamp):
     '''
 
     tt = time.gmtime(int(timestamp))
-    tts = tt[0:2] + (1, 0, 0, 0) + tt[6:9]
-    return calendar.timegm(tts)
+    tts = tt[0:2] + (1, 0, 0, 0)
+    return to_time_float(calendar.timegm(tts))
 
 
 def year_start(timestamp):
@@ -1054,8 +1324,8 @@ def year_start(timestamp):
     '''
 
     tt = time.gmtime(int(timestamp))
-    tts = tt[0:1] + (1, 1, 0, 0, 0) + tt[6:9]
-    return calendar.timegm(tts)
+    tts = tt[0:1] + (1, 1, 0, 0, 0)
+    return to_time_float(calendar.timegm(tts))
 
 
 def iter_days(tmin, tmax):
@@ -1224,6 +1494,8 @@ def str_to_time(s, format='%Y-%m-%d %H:%M:%S.OPTFRAC'):
     seconds.
     '''
 
+    time_float = get_time_float()
+
     if util_ext is not None:
         try:
             t, tfrac = util_ext.stt(s, format)
@@ -1231,7 +1503,7 @@ def str_to_time(s, format='%Y-%m-%d %H:%M:%S.OPTFRAC'):
             raise TimeStrError(
                 '%s, string=%s, format=%s' % (str(e), s, format))
 
-        return t+tfrac
+        return time_float(t)+tfrac
 
     fracsec = 0.
     fixed_endings = '.FRAC', '.1FRAC', '.2FRAC', '.3FRAC'
@@ -1261,7 +1533,8 @@ def str_to_time(s, format='%Y-%m-%d %H:%M:%S.OPTFRAC'):
             s = s[:dotpos]
 
     try:
-        return calendar.timegm(time.strptime(s, format)) + fracsec
+        return time_float(calendar.timegm(time.strptime(s, format))) \
+            + fracsec
     except ValueError as e:
         raise TimeStrError('%s, string=%s, format=%s' % (str(e), s, format))
 
@@ -1283,6 +1556,9 @@ def time_to_str(t, format='%Y-%m-%d %H:%M:%S.3FRAC'):
     with ``x`` digits precision.
     '''
 
+    if pyrocko.grumpy > 0:
+        check_time_class(t, 'warn' if pyrocko.grumpy == 1 else 'raise')
+
     if isinstance(format, int):
         if format > 0:
             format = '%Y-%m-%d %H:%M:%S.' + '%iFRAC' % format
@@ -1290,9 +1566,9 @@ def time_to_str(t, format='%Y-%m-%d %H:%M:%S.3FRAC'):
             format = '%Y-%m-%d %H:%M:%S'
 
     if util_ext is not None:
-        t0 = math.floor(t)
+        t0 = num.floor(t)
         try:
-            return util_ext.tts(int(t0), t - t0, format)
+            return util_ext.tts(int(t0), float(t - t0), format)
         except util_ext.UtilExtError as e:
             raise TimeStrError(
                 '%s, timestamp=%f, format=%s' % (str(e), t, format))
@@ -1689,6 +1965,60 @@ def match_nslcs(patterns, nslcs):
     return matching
 
 
+class Timeout(Exception):
+    pass
+
+
+def create_lockfile(fn, timeout=None, timewarn=10.):
+    t0 = time.time()
+
+    while True:
+        try:
+            f = os.open(fn, os.O_CREAT | os.O_WRONLY | os.O_EXCL)
+            os.close(f)
+            return
+
+        except OSError as e:
+            if e.errno == errno.EEXIST:
+                tnow = time.time()
+
+                if timeout is not None and tnow - t0 > timeout:
+                    raise Timeout(
+                        'Timeout (%gs) occured while waiting to get exclusive '
+                        'access to: %s' % (timeout, fn))
+
+                if timewarn is not None and tnow - t0 > timewarn:
+                    logger.warn(
+                        'Waiting since %gs to get exclusive access to: %s' % (
+                            timewarn, fn))
+
+                    timewarn *= 2
+
+                time.sleep(0.01)
+            else:
+                raise
+
+
+def delete_lockfile(fn):
+    os.unlink(fn)
+
+
+class Lockfile(Exception):
+
+    def __init__(self, path, timeout=5, timewarn=10.):
+        self._path = path
+        self._timeout = timeout
+        self._timewarn = timewarn
+
+    def __enter__(self):
+        create_lockfile(
+            self._path, timeout=self._timeout, timewarn=self._timewarn)
+        return None
+
+    def __exit__(self, type, value, traceback):
+        delete_lockfile(self._path)
+
+
 class SoleError(Exception):
     '''
     Exception raised by objects of type :py:class:`Sole`, when an concurrent
@@ -1727,6 +2057,12 @@ class Sole(object):
         ensuredirs(self._pid_path)
         self._lockfile = None
         self._os = os
+
+        if not fcntl:
+            raise SoleError(
+                'Python standard library module "fcntl" not available on '
+                'this platform.')
+
         self._fcntl = fcntl
 
         try:
@@ -1850,17 +2186,11 @@ class TableReader(object):
         if not line:
             self.eof = True
             return []
-        s = shlex.shlex(line, posix=True)
-        s.whitespace_split = True
-        s.whitespace = ' \t\n\r\f\v'  # compatible with re's \s
-        row = []
-        while True:
-            x = s.get_token()
-            if x is None:
-                break
-            row.append(x)
+        line.strip()
+        if line.startswith('#'):
+            return []
 
-        return row
+        return qsplit(line)
 
 
 def gform(number, significant_digits=3):
@@ -2062,7 +2392,9 @@ def read_leap_seconds2():
 
 
 def gps_utc_offset(t_utc):
-    '''Time offset t_gps - t_utc for a given t_utc.'''
+    '''
+    Time offset t_gps - t_utc for a given t_utc.
+    '''
     ls = read_leap_seconds2()
     i = 0
     if t_utc < ls[0][0]:
@@ -2077,7 +2409,9 @@ def gps_utc_offset(t_utc):
 
 
 def utc_gps_offset(t_gps):
-    '''Time offset t_utc - t_gps for a given t_gps.'''
+    '''
+    Time offset t_utc - t_gps for a given t_gps.
+    '''
     ls = read_leap_seconds2()
 
     if t_gps < ls[0][0] + ls[0][1] - 9:
@@ -2245,3 +2579,86 @@ def mpl_show(plt):
         logger.warning('Cannot show() when using matplotlib "agg" backend')
     else:
         plt.show()
+
+
+g_re_qsplit = re.compile(
+    r'"([^"\\]*(?:\\.[^"\\]*)*)"|\'([^\'\\]*(?:\\.[^\'\\]*)*)\'|(\S+)')
+
+
+g_re_trivial = re.compile(r'\A[^\'"\s]+\Z')
+g_re_escape_s = re.compile(r'([\\\'])')
+g_re_unescape_s = re.compile(r'\\([\\\'])')
+g_re_escape_d = re.compile(r'([\\"])')
+g_re_unescape_d = re.compile(r'\\([\\"])')
+
+
+def escape_s(s):
+    '''
+    Backslash-escape single-quotes and backslashes.
+
+    Example: ``Jack's`` => ``Jack\\'s``
+
+    '''
+    return g_re_escape_s.sub(r'\\\1', s)
+
+
+def unescape_s(s):
+    '''
+    Unescape backslash-escaped single-quotes and backslashes.
+
+    Example: ``Jack\\'s`` => ``Jack's``
+    '''
+    return g_re_unescape_s.sub(r'\1', s)
+
+
+def escape_d(s):
+    '''
+    Backslash-escape double-quotes and backslashes.
+
+    Example: ``"Hello \\O/"`` => ``\\"Hello \\\\O/\\"``
+    '''
+    return g_re_escape_d.sub(r'\\\1', s)
+
+
+def unescape_d(s):
+    '''
+    Unescape backslash-escaped double-quotes and backslashes.
+
+    Example:  ``\\"Hello \\\\O/\\"`` => ``"Hello \\O/"``
+    '''
+    return g_re_unescape_d.sub(r'\1', s)
+
+
+def qjoin_s(it):
+    '''
+    Join sequence of strings into a line, single-quoting non-trivial strings.
+
+    Example:  ``["55", "Sparrow's Island"]`` => ``"55 'Sparrow\\\\'s Island'"``
+    '''
+    return ' '.join(
+        w if g_re_trivial.search(w) else "'%s'" % escape_s(w) for w in it)
+
+
+def qjoin_d(it):
+    '''
+    Join sequence of strings into a line, double-quoting non-trivial strings.
+
+    Example:  ``['55', 'Pete "The Robot" Smith']`` =>
+    ``'55' "Pete \\\\"The Robot\\\\" Smith"'``
+    '''
+    return ' '.join(
+        w if g_re_trivial.search(w) else '"%s"' % escape_d(w) for w in it)
+
+
+def qsplit(s):
+    '''
+    Split line into list of strings, allowing for quoted strings.
+
+    Example:  ``"55 'Sparrow\\\\'s Island'"`` =>
+    ``["55", "Sparrow's Island"]``,
+    ``'55' "Pete \\\\"The Robot\\\\" Smith"'`` =>
+    ``['55', 'Pete "The Robot" Smith']``
+    '''
+    return [
+        (unescape_d(x[0]) or unescape_s(x[1]) or x[2])
+        for x in g_re_qsplit.findall(s)]
